Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
tests\test_bool_array.py | 46 | 0 | 0 | 100%
tests\test_get_module_device.py | 27 | 8 | 0 | 70%
tests\test_isolate_zanj_handler_store.py | 47 | 1 | 0 | 98%
tests\test_zanj_basic.py | 35 | 0 | 0 | 100%
tests\test_zanj_populate_nested.py | 24 | 0 | 0 | 100%
tests\test_zanj_sdc_modelcfg.py | 90 | 0 | 0 | 100%
tests\test_zanj_serializable_dataclass.py | 128 | 1 | 0 | 99%
tests\test_zanj_torch.py | 88 | 4 | 0 | 95%
tests\test_zanj_torch_cfgmismatch.py | 59 | 3 | 0 | 95%
zanj\__init__.py | 4 | 4 | 0 | 0%
zanj\externals.py | 21 | 1 | 0 | 95%
zanj\loading.py | 126 | 25 | 0 | 80%
zanj\serializing.py | 59 | 4 | 0 | 93%
zanj\torchutil.py | 113 | 13 | 0 | 88%
zanj\zanj.py | 83 | 5 | 0 | 94%
Total | 950 | 69 | 0 | 93%

No items found using the specified filter.